@@ -37,6 +37,7 @@
 
 #if defined(COMPILE_FOR_AUDACIOUS)
 #  define ConfigFile ConfigDb
+#if __AUDACIOUS_PLUGIN_API__ <= 6
 #  define xmms_cfg_read_int           bmp_cfg_db_get_int
 #  define xmms_cfg_read_string        bmp_cfg_db_get_string
 #  define xmms_cfg_read_boolean       bmp_cfg_db_get_bool
@@ -46,14 +47,25 @@
 #  define xmms_cfg_remove_key         bmp_cfg_db_unset_key
 #  define xmms_cfg_open_default_file  bmp_cfg_db_open
 #  define xmms_cfg_write_default_file bmp_cfg_db_close
+#else
+#  define xmms_cfg_read_int           aud_cfg_db_get_int
+#  define xmms_cfg_read_string        aud_cfg_db_get_string
+#  define xmms_cfg_read_boolean       aud_cfg_db_get_bool
+#  define xmms_cfg_write_int          aud_cfg_db_set_int
+#  define xmms_cfg_write_string       aud_cfg_db_set_string
+#  define xmms_cfg_write_boolean      aud_cfg_db_set_bool
+#  define xmms_cfg_remove_key         aud_cfg_db_unset_key
+#  define xmms_cfg_open_default_file  aud_cfg_db_open
+#  define xmms_cfg_write_default_file aud_cfg_db_close
+#endif
 void xmms_cfg_dummy(ConfigDb *dummy) { }
 #  define xmms_cfg_free xmms_cfg_dummy
 #endif
 
 
 /* init with DEFAULT_CFG to make sure all string pointers are set to NULL */
-config_t _cfg = CONFIG_DEFAULT;  /* also used in configure.c */
-static config_t *cfg = &_cfg;
+config_t _xfg = CONFIG_DEFAULT;  /* also used in configure.c */
+static config_t *xfg = &_xfg;
 
 /*****************************************************************************/
 
@@ -404,8 +416,6 @@ xfade_load_config()
 #ifdef PRESET_SUPPORT
 #ifdef COMPILE_FOR_AUDACIOUS
 	filename = g_strconcat(g_get_home_dir(), "/.audacious/crossfade-presets", NULL);
-#elsif defined(COMPILE_FOR_BMP)
-	filename = g_strconcat(g_get_home_dir(), "/.bmp/crossfade-presets", NULL);
 #else
 	filename = g_strconcat(g_get_home_dir(), "/.xmms/crossfade-presets", NULL);
 #endif
@@ -525,10 +535,10 @@ xfade_save_config()
 void
 xfade_free_config()
 {
-	SAFE_FREE(cfg->oss_alt_audio_device);
-	SAFE_FREE(cfg->oss_alt_mixer_device);
-	SAFE_FREE(cfg->op_config_string);
-	SAFE_FREE(cfg->op_name);
+	SAFE_FREE(xfg->oss_alt_audio_device);
+	SAFE_FREE(xfg->oss_alt_mixer_device);
+	SAFE_FREE(xfg->op_config_string);
+	SAFE_FREE(xfg->op_name);
 
 	g_list_foreach(config->presets, g_free_f, NULL);
 	g_list_free(config->presets);
@@ -709,7 +719,7 @@ xfade_cfg_fadein_volume(fade_config_t *fc)
 gboolean
 xfade_cfg_gap_trail_enable(config_t *cfg)
 {
-	return cfg->gap_trail_locked ? cfg->gap_lead_enable : cfg->gap_trail_enable;
+	return xfg->gap_trail_locked ? xfg->gap_lead_enable : xfg->gap_trail_enable;
 }
 
 gint
@@ -718,29 +728,29 @@ xfade_cfg_gap_trail_len(config_t *cfg)
 	if (!xfade_cfg_gap_trail_enable(cfg))
 		return 0;
 
-	return cfg->gap_trail_locked ? cfg->gap_lead_len_ms : cfg->gap_trail_len_ms;
+	return xfg->gap_trail_locked ? xfg->gap_lead_len_ms : xfg->gap_trail_len_ms;
 }
 
 gint
 xfade_cfg_gap_trail_level(config_t *cfg)
 {
-	return cfg->gap_trail_locked ? cfg->gap_lead_level : cfg->gap_trail_level;
+	return xfg->gap_trail_locked ? xfg->gap_lead_level : xfg->gap_trail_level;
 }
 
 gint
 xfade_mix_size_ms(config_t *cfg)
 {
-	if (cfg->mix_size_auto)
+	if (xfg->mix_size_auto)
 	{
 		gint i, min_size = 0;
 
 		for (i = 0; i < MAX_FADE_CONFIGS; i++)
 		{
-			gint size = xfade_cfg_fadeout_len(&cfg->fc[i]);
-			gint offset = xfade_cfg_offset(&cfg->fc[i]);
+			gint size = xfade_cfg_fadeout_len(&xfg->fc[i]);
+			gint offset = xfade_cfg_offset(&xfg->fc[i]);
 
-			if (cfg->fc[i].type == FADE_TYPE_PAUSE_ADV)
-				size += xfade_cfg_fadein_len(&cfg->fc[i]);
+			if (xfg->fc[i].type == FADE_TYPE_PAUSE_ADV)
+				size += xfade_cfg_fadein_len(&xfg->fc[i]);
 
 			if (size < -offset)
 				size = -offset;
@@ -748,10 +758,10 @@ xfade_mix_size_ms(config_t *cfg)
 			if (size > min_size)
 				min_size = size;
 		}
-		return min_size += xfade_cfg_gap_trail_len(cfg) + cfg->songchange_timeout;
+		return min_size += xfade_cfg_gap_trail_len(cfg) + xfg->songchange_timeout;
 	}
 	else
-		return cfg->mix_size_ms;
+		return xfg->mix_size_ms;
 }
 
 /*****************************************************************************/
