@@ -96,6 +96,32 @@ static struct
 	OutputPlugin xfade_op;
         void (*cleanup) (void);
 }
+#if defined(COMPILE_FOR_AUDACIOUS)
+xfade_op_private =
+{
+	{
+		.description    = "Crossfade Plugin " VERSION,
+		.init           = xfade_init,
+		.cleanup        = xfade_cleanup,
+		.get_volume     = xfade_get_volume,
+		.set_volume     = xfade_set_volume,
+		.open_audio     = xfade_open_audio,
+		.write_audio    = xfade_write_audio,
+		.close_audio    = xfade_close_audio,
+		.flush          = xfade_flush,
+		.pause          = xfade_pause,
+		.buffer_free    = xfade_buffer_free,
+		.buffer_playing = xfade_buffer_playing,
+		.output_time    = xfade_output_time,
+		.written_time   = xfade_written_time,
+#if defined(HAVE_GTK)
+		.about          = xfade_about,
+		.configure      = xfade_configure,
+#endif
+	},
+	NULL
+};
+#else
 xfade_op_private =
 {
 	{
@@ -103,9 +129,6 @@ xfade_op_private =
 		NULL,
 		"Crossfade Plugin " VERSION,
 		xfade_init,
-#if defined(COMPILE_FOR_AUDACIOUS)
-		xfade_cleanup,
-#endif
 #if defined(HAVE_GTK)
 		xfade_about,
 		xfade_configure,
@@ -124,18 +147,16 @@ xfade_op_private =
 		xfade_buffer_playing,
 		xfade_output_time,
 		xfade_written_time,
-#if defined(COMPILE_FOR_AUDACIOUS)
-		NULL
-	},
-	NULL
-#else
 	},
 	xfade_cleanup
-#endif
 };
+#endif
 
 static OutputPlugin *xfade_op = &xfade_op_private.xfade_op;
-
+#if AUDACIOUS_ABI_VERSION >= 2
+static OutputPlugin *xfade_oplist[] = { &xfade_op_private.xfade_op, NULL };
+DECLARE_PLUGIN(crossfade, NULL, NULL, NULL, xfade_oplist, NULL, NULL, NULL);
+#endif
 
 /* internal prototypes */
 static void load_symbols();
@@ -154,22 +175,6 @@ static char *  (*playlist_get_fadeinfo)(int)  = NULL;   /* XMMS patch */
 static void (*xmms_input_get_song_info)(gchar *, gchar **, gint *); /* XMMS */
 static gchar **xmms_gentitle_format = NULL;   /* XMMS private cfg */
 
-#if defined(COMPILE_FOR_BMP) || defined(COMPILE_FOR_AUDACIOUS)
-#if defined(AUDACIOUS_NEW_ABI)
-gboolean playback_get_playing();  /* >= Audacious-1.3.0 */
-gboolean get_input_playing()
-{
-	return playback_get_playing();
-}
-#else
-gboolean bmp_playback_get_playing();  /* Audacious, BMP */
-gboolean get_input_playing()
-{
-	return bmp_playback_get_playing();
-}
-#endif
-#endif
-
 #ifdef HAVE_CTOR
 void fini() __attribute__ ((destructor));
 #else
@@ -180,8 +185,31 @@ void _fini()
 }
 #endif
 
+/* This function has been stolen from libxmms/util.c. */
+void xfade_usleep(gint usec)
+{
+#if defined(HAVE_G_USLEEP)
+	g_usleep(usec);
+#elif defined(HAVE_NANOSLEEP)
+	struct timespec req;
+
+	req.tv_sec = usec / 1000000;
+	usec -= req.tv_sec * 1000000;
+	req.tv_nsec = usec * 1000;
+
+	nanosleep(&req, NULL);
+#else
+	struct timeval tv;
+
+	tv.tv_sec = usec / 1000000;
+	usec -= tv.tv_sec * 1000000;
+	tv.tv_usec = usec;
+	select(0, NULL, NULL, NULL, &tv);
+#endif
+}
+
+
 /* local variables */
-static gint session_id;
 static gboolean realtime;
 static gboolean is_http;
 
@@ -286,7 +314,8 @@ static THREAD buffer_thread;
 static effect_context_t  effect_context;
 static convert_context_t convert_context;
 static rate_context_t    rate_context;
-static volume_context_t  volume_context;
+static volume_context_t  normalizer_context;
+static volume_context_t  swmixer_context;
 #ifdef HAVE_LIBFFTW
 static fft_context_t fft_context;
 #endif
@@ -335,7 +364,7 @@ xfade_realize_ep_config()
 	EffectPlugin *ep = NULL;
 
 	/* find effect plugin */
-	if (config->ep_enable && config->ep_name && (list = get_effect_list()))	/* XMMS */
+	if (config->ep_enable && config->ep_name && (list = xfplayer_get_effect_list()))
 		if ((element = g_list_find_custom(list, config->ep_name, effect_list_f)))
 			ep = element->data;
 
@@ -350,17 +379,24 @@ xfade_realize_config()		/* also called by xfade_init() */
 
 #ifdef VOLUME_NORMALIZER
 	/* update volume normalizer target rms */
-
-	volume_set_target_rms(&volume_context, config->volnorm_target);
+	volume_set_target_rms(&normalizer_context, config->volnorm_target);
 #endif
 
+	/* enable/disable software mixer */
+	volume_set_active(&swmixer_context, config->enable_mixer && config->mixer_software);
+	volume_set(&swmixer_context,
+	           config->mixer_reverse ? config->mixer_vol_right
+	                                 : config->mixer_vol_left,
+	           config->mixer_reverse ? config->mixer_vol_left
+	                                 : config->mixer_vol_right);
+	
 	/* 0.3.0: keep device opened */
 	if (config->output_keep_opened && !output_opened)
 	{
 		DEBUG(("[crossfade] realize_config: keeping output opened...\n"));
 
 		/* HACK: avoid rate converter complaing about illegal input rate */
-		/* if(!rate_context.valid || !rate_context.in_rate)
+		/* if (!rate_context.valid || !rate_context.in_rate)
 		   rate_config(&rate_context, out_format.rate, out_format.rate); */
 
 		/* 0.3.1: HACK: this will make sure that we start playing silence after startup */
@@ -401,7 +437,7 @@ find_output()
 	}
 	else if (config->output_method == OUTPUT_METHOD_PLUGIN)
 	{
-		if (config->op_name && (list = get_output_list()))	/* XMMS */
+		if (config->op_name && (list = xfplayer_get_output_list()))
 			if ((element = g_list_find_custom(list, config->op_name, output_list_f)))
 				op = element->data;
 
@@ -522,12 +558,7 @@ open_output()
 	stopped = FALSE;
 
 	/* create and run buffer thread */
-#if defined(HAVE_GLIB_STATIC_MUTEX)
-	buffer_thread = g_thread_create((GThreadFunc) buffer_thread_f, NULL, TRUE, NULL);
-	if (buffer_thread == NULL)
-#else
-	if (pthread_create(&buffer_thread, NULL, buffer_thread_f, NULL))
-#endif
+	if (THREAD_CREATE(buffer_thread, buffer_thread_f))
 	{
 		PERROR("[crossfade] open_output: thread_create()");
 		g_free(buffer->data);
@@ -535,9 +566,7 @@ open_output()
 		the_op = NULL;
 		return -1;
 	}
-#ifdef _POSIX_PRIORITY_SCHEDULING 
-	sched_yield();
-#endif
+	SCHED_YIELD;
 
 	/* start updating monitor */
 	xfade_start_monitor();
@@ -562,7 +591,7 @@ xfade_init()
 	if (!config->op_name)              config->op_name              = g_strdup(DEFAULT_OP_NAME);
 
 	/* check for realtime priority, it needs some special attention */
-	realtime = xmms_check_realtime_priority();
+	realtime = xfplayer_check_realtime_priority();
 
 	/* show monitor win if enabled in config */
 	xfade_check_monitor_win();
@@ -571,7 +600,8 @@ xfade_init()
 	effect_init (&effect_context, NULL);
 	convert_init(&convert_context);
 	rate_init   (&rate_context);
-	volume_init (&volume_context);
+	volume_init (&normalizer_context);
+	volume_init (&swmixer_context);
 #ifdef HAVE_LIBFFTW
 	fft_init(&fft_context);
 #endif
@@ -584,9 +614,6 @@ xfade_init()
 	if (!(the_op = find_output()))
 		DEBUG(("[crossfade] init: could not find any output!\n"));
 
-	/* get xmms controlsocket session id */
-	session_id = ctrlsocket_get_session_id();
-
 	/* load any dynamic linked symbols */
 	load_symbols();
 
@@ -657,7 +684,9 @@ load_symbols()
 static void
 output_list_hack()
 {
-	GList *output_list = get_output_list();
+	GList *output_list = xfplayer_get_output_list();
+	if (!output_list)
+		return;
 
 	int i0 = g_list_index(output_list, xfade_op), i1;
 
@@ -690,9 +719,7 @@ fini()
 	 * opened before.
 	 */
 	if (output_opened)
-	{
 		DEBUG(("[crossfade] fini: WARNING: output still opened, lockup imminent!\n"));
-	}
 
 	/* reset last_close so that the buffer thread will
 	 * not unnecessarily wait for a timeout. */
@@ -703,12 +730,19 @@ fini()
 
 	/* wait for buffer thread to clean up and terminate */
 	DEBUG(("[crossfade] fini: cleanup: waiting for buffer thread...\n"));
-	while (output_opened)  /* output_opened) */
+#if 0
+	MUTEX_UNLOCK(&buffer_mutex);
+	if (THREAD_JOIN(buffer_thread))
+		PERROR("[crossfade] close: thread_join()");
+	MUTEX_LOCK(&buffer_mutex);
+#else
+	while (output_opened)
 	{
 		MUTEX_UNLOCK(&buffer_mutex);
-		xmms_usleep(10000);
+		xfade_usleep(10000);
 		MUTEX_LOCK(&buffer_mutex);
 	}
+#endif
 	DEBUG(("[crossfade] fini: cleanup: waiting for buffer thread... done\n"));
 	
 	/* HACK: 0.3.5: close output plugin from THIS thread */
@@ -740,7 +774,8 @@ fini()
 #ifdef HAVE_LIBFFTW
 	fft_free(&fft_context);
 #endif
-	volume_free (&volume_context);
+	volume_free (&swmixer_context);
+	volume_free (&normalizer_context);
 	rate_free   (&rate_context);
 	convert_free(&convert_context);
 	effect_free (&effect_context);
@@ -768,16 +803,12 @@ xfade_get_volume(int *l, int *r)
 {
 	if (config->mixer_software)
 	{
-		if (config->mixer_reverse)
-		{
-			*l = config->mixer_vol_right;
-			*r = config->mixer_vol_left;
-		}
-		else
-		{
-			*l = config->mixer_vol_left;
-			*r = config->mixer_vol_right;
-		}
+		*l = config->mixer_reverse
+		   ? config->mixer_vol_right
+		   : config->mixer_vol_left;
+		*r = config->mixer_reverse
+		   ? config->mixer_vol_left
+		   : config->mixer_vol_right;
 	}
 	else
 	{
@@ -789,11 +820,15 @@ xfade_get_volume(int *l, int *r)
 				the_op->get_volume(l, r);
 		}
 	}
+
+	/* DEBUG(("[crossfade] xfade_get_volume: l=%d r=%d\n", *l, *r)); */
 }
 
 void
 xfade_set_volume(int l, int r)
 {
+	/* DEBUG(("[crossfade] xfade_set_volume: l=%d r=%d\n", l, r)); */
+
 	if (!config->enable_mixer)
 		return;
 
@@ -801,13 +836,15 @@ xfade_set_volume(int l, int r)
 	{
 		if (config->mixer_reverse)
 		{
-			config->mixer_vol_right = l;
+			volume_set(&swmixer_context, r, l);
 			config->mixer_vol_left  = r;
+			config->mixer_vol_right = l;
 		}
 		else
 		{
-			config->mixer_vol_right = r;
+			volume_set(&swmixer_context, l, r);
 			config->mixer_vol_left  = l;
+			config->mixer_vol_right = r;
 		}
 	}
 	else
@@ -1137,17 +1174,14 @@ xfade_open_audio(AFormat fmt, int rate, int nch)
 		DEBUG(("[crossfade] open_audio: WARNING: already opened!\n"));
 
 	/* get filename */
-#ifdef HAVE_PLAYLIST_GET_FILENAME
-	pos     = get_playlist_position();      /* XMMS */
-	file    = playlist_get_filename(pos);   /* XMMS */
-	title   = playlist_get_songtitle(pos);  /* XMMS */
+	pos     = xfplaylist_get_position ();
+	file    = xfplaylist_get_filename (pos);
+	title   = xfplaylist_get_songtitle(pos);
 	comment = playlist_get_fadeinfo ? playlist_get_fadeinfo(pos) : NULL;
-#else
-	pos     = xmms_remote_get_playlist_pos  (session_id);
-	file    = xmms_remote_get_playlist_file (session_id, pos);
-	title   = xmms_remote_get_playlist_title(session_id, pos);
-	comment = NULL;
-#endif
+
+	if (!file)
+		file = g_strdup(title);
+		
 	DEBUG(("[crossfade] open_audio: bname=\"%s\"\n", g_basename(file)));
 	DEBUG(("[crossfade] open_audio: title=\"%s\"\n", title));
 
@@ -1238,7 +1272,7 @@ xfade_open_audio(AFormat fmt, int rate, int nch)
 	if (fade_config == &config->fc[FADE_CONFIG_XFADE])
 	{
 		DEBUG(("*** XFADE:\n"));
-		int current_length = PLAYLIST_GET_CURRENT_LENGTH;
+		int current_length = playlist_get_current_length();
 		DEBUG(("*** length=%d\n", current_length));
 		if (current_length < 30 * 1000)
 			fade_config = &config->fc[FADE_CONFIG_ALBUM];
@@ -1247,7 +1281,7 @@ xfade_open_audio(AFormat fmt, int rate, int nch)
 
 #ifdef VOLUME_NORMALIZER
 	/* turn off volume normalizing per default, until we get a target RMS for this song */
-	volume_set_active(&volume_context, FALSE);
+	volume_set_active(&normalizer_context, FALSE);
 
 	/* thomas: add support for quantaudio per-song mixing info */
 	if (config->volnorm_use_qa)
@@ -1263,8 +1297,8 @@ xfade_open_audio(AFormat fmt, int rate, int nch)
 			DEBUG(("[crossfade] open_audio: quantaudio comment found:\n"));
 			DEBUG(("[crossfade] open_audio: ... RMS=%d, mix_in=%.2f, mix_out=%.2f, length=%.2f\n",
 			       qa.RMS, qa.mix_in, qa.mix_out, qa.length));
-			volume_set_song_rms(&volume_context, qa.RMS);
-			volume_set_active(&volume_context, TRUE);
+			volume_set_song_rms(&normalizer_context, qa.RMS);
+			volume_set_active  (&normalizer_context, TRUE);
 		}
 		else
 			DEBUG(("[crossfade] open_audio: no quantaudio comment found\n"));
@@ -1274,8 +1308,9 @@ xfade_open_audio(AFormat fmt, int rate, int nch)
 		have_qa = FALSE;
 	/* thomas: end */
 
-	if (volume_context.active && config->volnorm_enable)
-		DEBUG(("[crossfade] open_audio: volume normalizer: factor=%.3f\n", volume_context.factor));
+	if (normalizer_context.active && config->volnorm_enable)
+		DEBUG(("[crossfade] open_audio: volume normalizer: factor=%.3f\n",
+		       normalizer_context.factor));
 #endif
 
 #ifdef TIMING_COMMENTS
@@ -1556,7 +1591,7 @@ xfade_write_audio(void *ptr, int length)
 #ifdef VOLUME_NORMALIZER
 	/* normalize volume */
 	if (config->volnorm_enable)
-		volume_flow(&volume_context, (gpointer *) &ptr, length);
+		volume_flow(&normalizer_context, (gpointer *) &ptr, length);
 #endif
 
 	/* lock buffer */
@@ -1810,7 +1845,7 @@ sync_output()
 
 		/* yield */
 		MUTEX_UNLOCK(&buffer_mutex);
-		xmms_usleep(10000);
+		xfade_usleep(10000);
 		MUTEX_LOCK(&buffer_mutex);
 	}
 
@@ -1856,7 +1891,7 @@ buffer_thread_f(void *arg)
 		DEBUG(("[crossfade] buffer_thread_f: yielding...\n"));
 #endif
 		MUTEX_UNLOCK(&buffer_mutex);
-		xmms_usleep(10000);
+		xfade_usleep(10000);
 		MUTEX_LOCK(&buffer_mutex);
 
 		/* --------------------------------------------------------------------- */
@@ -1866,13 +1901,14 @@ buffer_thread_f(void *arg)
 		/* V0.3.0: New timeout detection */
 		if (!opened)
 		{
-			gboolean current = get_input_playing();	/* XMMS */
+			gboolean current = xfplayer_input_playing();
 
 			/* also see fini() */
 			if (last_close.tv_sec || last_close.tv_usec)
 			{
 				gettimeofday(&tv, NULL);
-				timeout = (tv.tv_sec - last_close.tv_sec) * 1000 + (tv.tv_usec - last_close.tv_usec) / 1000;
+				timeout = (tv.tv_sec  - last_close.tv_sec)  * 1000
+				        + (tv.tv_usec - last_close.tv_usec) / 1000;
 			}
 			else
 				timeout = -1;
@@ -1881,12 +1917,10 @@ buffer_thread_f(void *arg)
 			{
 				input_playing = current;
 				
-				/* *INDENT-OFF* */
 				if (current)
 					DEBUG(("[crossfade] buffer_thread_f: input restarted after %ld ms\n", timeout))
 				else
 					DEBUG(("[crossfade] buffer_thread_f: input stopped after + %ld ms\n", timeout));
-				/* *INDENT-ON* */
 			}
 
 			/* 0.3.0: HACK: output_keep_opened: play silence during prebuffering */
@@ -1922,7 +1956,8 @@ buffer_thread_f(void *arg)
 
 		/* calculate time since last write to the buffer (ignore overflows) */
 		gettimeofday(&tv, NULL);
-		timeout = (tv.tv_sec - last_write.tv_sec) * 1000 + (tv.tv_usec - last_write.tv_usec) / 1000;
+		timeout = (tv.tv_sec  - last_write.tv_sec)  * 1000
+		        + (tv.tv_usec - last_write.tv_usec) / 1000;
 
 		/* check for timeout/eop (note this is the only way out of this loop) */
 		if (stopping)
@@ -2031,31 +2066,12 @@ buffer_thread_f(void *arg)
 
 			if (output_flush_time != output_time)
 			{
-#if 0  // defined(SONGCHANGE_TIMEOUT)
-				if (timeout < config->songchange_timeout)
-				{
-					/* slow down output, but always write _some_ data */
-					if (output_limit < in_format.bps / 100 / 2)
-						output_limit = in_format.bps / 100 / 2;
-
-					if (op_free > output_limit)
-						op_free = output_limit;
-				}
-				else
-				{
-					if ((output_used < config->op_max_used_ms) && (op_free > output_limit))
-						op_free = output_limit;
-					else
-						op_free = MIN(op_free, 2304);	/* avoid 0 */
-				}
-#else
 				/* slow down output, but always write _some_ data */
 				if (output_limit < in_format.bps / 100 / 2)
 					output_limit = in_format.bps / 100 / 2;
 
 				if (op_free > output_limit)
 					op_free = output_limit;
-#endif
 			}
 		}
 
@@ -2101,7 +2117,8 @@ buffer_thread_f(void *arg)
 				if (realtime)
 				{
 					gettimeofday(&tv, NULL);
-					dt = (tv.tv_sec - mark.tv_sec) * 1000 + (tv.tv_usec - mark.tv_usec) / 1000;
+					dt = (tv.tv_sec  - mark.tv_sec)  * 1000
+					   + (tv.tv_usec - mark.tv_usec) / 1000;
 					if (dt >= 10)
 						break;
 				}
@@ -2121,11 +2138,7 @@ buffer_thread_f(void *arg)
 				length = op_free;
 
 			/* HACK: throttle output (used with fast output plugins) */
-#if 0  // defined(SONGCHANGE_TIMEOUT)
-			if (the_op_config.throttle_enable && !realtime && opened && (timeout < config->songchange_timeout))
-#else
 			if (the_op_config.throttle_enable && !realtime && opened)
-#endif
 			{
 				sync = buffer->sync_size - (buffer->size - buffer->used);
 				if      (sync < 0)      length = 0;
@@ -2169,6 +2182,9 @@ buffer_thread_f(void *arg)
 				/* fft playground */
 				fft_flow(&fft_context, (gpointer) data, blen);
 #endif
+				/* apply software mixer just before writing to output plugin */
+				if (config->mixer_software)
+					volume_flow(&swmixer_context, (gpointer) data, blen);
 
 				/* finally, write data */
 				the_op->write_audio(data, blen);
@@ -2315,6 +2331,8 @@ void
 xfade_close_audio()
 {
 	DEBUG(("[crossfade] close:\n"));
+	DEBUG(("[crossfade] close: playing=%d filename=%s\n",
+	       xfplayer_input_playing(), xfplaylist_get_filename(xfplaylist_get_position())));
 
 	/* lock buffer */
 	MUTEX_LOCK(&buffer_mutex);
@@ -2327,7 +2345,20 @@ xfade_close_audio()
 		return;
 	}
 
-	/* HACK: FIXME */
+#if defined(COMPILE_FOR_AUDACIOUS) && AUDACIOUS_ABI_VERSION >= 2
+	/* HACK: to distinguish between STOP and EOP, check Audacious'
+	   input_playing() variable. It seems to be TRUE at this point
+	   only when the end of the playlist is reached.
+	   
+	   Normally, 'playing' is constantly being updated in the
+	   xfade_buffer_playing() callback, but Audacious does not seem
+	   to use it. Therefore, we can set 'playing' to FALSE here,
+	   which later 'buffer_thread' will interpret as EOP (see above).
+	*/
+	if (xfplayer_input_playing())
+		playing = FALSE;
+#else
+	/* HACK: use patched XMMS 'input_stopped_for_restart' */
 	if (input_stopped_for_restart && *input_stopped_for_restart)
 	{
 		DEBUG(("[crossfade] close: playback will restart soon\n"));
@@ -2335,6 +2366,7 @@ xfade_close_audio()
 	}
 	else
 		output_restart = FALSE;
+#endif
 
 	if (playing)
 	{
@@ -2388,7 +2420,7 @@ xfade_close_audio()
 			while (output_opened)
 			{
 				MUTEX_UNLOCK(&buffer_mutex);
-				xmms_usleep(10000);
+				xfade_usleep(10000);
 				MUTEX_LOCK(&buffer_mutex);
 			}
 #endif
@@ -2418,12 +2450,13 @@ xfade_close_audio()
 			{
 				gint wr_xedni = (buffer->rd_index + buffer->used - 1) % buffer->size + 1;
 				gint     blen = MIN(length, wr_xedni);
-				gint16     *p = buffer->data + wr_xedni;
+				gint16     *p = buffer->data + wr_xedni, left, right;
 				gint    index = 0;
 
 				while (index < blen)
 				{
-					gint16 right = *--p, left = *--p;
+					right = *--p;
+					left  = *--p;
 					if (ABS(left)  >= gap_level) break;
 					if (ABS(right) >= gap_level) break;
 					index += 4;
@@ -2452,12 +2485,12 @@ xfade_close_audio()
 				{
 					gint wr_xedni = (buffer->rd_index + buffer->used - 1) % buffer->size + 1;
 					gint     blen = MIN(buffer->used, wr_xedni);
-					gint16     *p = buffer->data + wr_xedni;
+					gint16     *p = buffer->data + wr_xedni, left;
 					gint    index = 0;
 
 					while (index < blen)
 					{
-						gint16 left = (--p, *--p);
+						left = (--p, *--p);
 						if ((crossing & 1) ^ (left > 0))
 							break;
 						index += 4;
@@ -2499,20 +2532,21 @@ xfade_flush(gint time)
 	DEBUG(("[crossfade] flush: time=%d\n", time));
 
 	/* get filename */
-#ifdef HAVE_PLAYLIST_GET_FILENAME
-	pos     = get_playlist_position();      /* XMMS */
-	file    = playlist_get_filename(pos);   /* XMMS */
-#else
-	pos     = xmms_remote_get_playlist_pos  (session_id);
-	file    = xmms_remote_get_playlist_file (session_id, pos);
-#endif
+	pos  = xfplaylist_get_position();
+	file = xfplaylist_get_filename(pos);
+	
+	if (!file)
+		file = g_strdup(xfplaylist_get_songtitle(pos));
 
 #if defined(COMPILE_FOR_AUDACIOUS)
-	/* HACK: special handling for audacious, which only calls flush(0) on a songchange */
+	/* HACK: special handling for audacious, which just calls flush(0) on a songchange */
 	if (file && last_filename && strcmp(file, last_filename) != 0)
 	{
 		DEBUG(("[crossfade] flush: filename changed, forcing close/reopen...\n"));
 		xfade_close_audio();
+		/* 0.3.14: xfade_close_audio sets fade_config to FADE_CONFIG_MANUAL,
+		 *         but this is an automatic songchange */
+		fade_config = &config->fc[FADE_CONFIG_XFADE];
 		xfade_open_audio(in_format.fmt, in_format.rate, in_format.nch);
 		DEBUG(("[crossfade] flush: filename changed, forcing close/reopen... done\n"));
 		return;
@@ -2582,9 +2616,9 @@ xfade_pause(short p)
 		{
 			int fade, length, n;
 			int index = buffer->rd_index;
-			int out_len = MS2B(xfade_cfg_fadeout_len(fc)) & -4;
-			int in_len = MS2B(xfade_cfg_fadein_len(fc)) & -4;
-			int silence_len = MS2B(xfade_cfg_offset(fc)) & -4;
+			int out_len     = MS2B(xfade_cfg_fadeout_len(fc)) & -4;
+			int in_len      = MS2B(xfade_cfg_fadein_len(fc))  & -4;
+			int silence_len = MS2B(xfade_cfg_offset(fc))      & -4;
 
 			/* limit fadeout/fadein len to available data in buffer */
 			if ((out_len + in_len) > buffer->used)
@@ -2644,7 +2678,7 @@ xfade_pause(short p)
 			buffer->silence = out_len;
 			buffer->silence_len = silence_len;
 			buffer->pause = out_len + silence_len;
-			paused = FALSE;	/* (!) will be set to TRUE in buffer_thread_f */
+			paused = FALSE;	 /* (!) will be set to TRUE in buffer_thread_f */
 		}
 		else
 		{
