@@ -28,7 +28,9 @@
 #  include "config.h"
 #endif
 
-#include <pthread.h>
+#if !defined(HAVE_GLIB_THREADS)
+#  include <pthread.h>
+#endif
 #include <glib.h>
 
 #if defined(COMPILE_FOR_XMMS) || defined(COMPILE_FOR_NOXMMS)
@@ -36,16 +38,14 @@
 #  include <xmms/xmmsctrl.h>
 #  include <xmms/configfile.h>
 #  include <xmms/util.h>
-#endif
-#if defined(COMPILE_FOR_BMP)
-#  include <bmp/plugin.h>
-#  include <bmp/beepctrl.h>
-#  include <bmp/configfile.h>
-#  include <bmp/util.h>
-#endif
-#if defined(COMPILE_FOR_AUDACIOUS)
+#elif defined(COMPILE_FOR_AUDACIOUS)
 #  include <audacious/plugin.h>
-#  include <audacious/beepctrl.h>
+#  include <audacious/playlist.h>
+#  if AUDACIOUS_ABI_VERSION >= 2
+#    include <audacious/auddrct.h>
+#  else
+#    include <audacious/beepctrl.h>
+#  endif
 #  include <audacious/configdb.h>
 #  include <audacious/util.h>
 #endif
@@ -355,25 +355,10 @@
 OutputPlugin *get_oplugin_info();
 OutputPlugin *get_crossfade_oplugin_info();
 
-/* xmms internal prototypes */
-/* XMMS */
-gint ctrlsocket_get_session_id();
-gboolean get_input_playing();
-GList *get_output_list();
-GList *get_effect_list();
-gint get_playlist_position();
-#if defined(AUDACIOUS_NEW_ABI)
-struct Playlist *playlist_get_active();
-gint playlist_get_current_length(struct Playlist *);
-#define PLAYLIST_GET_CURRENT_LENGTH playlist_get_current_length(playlist_get_active())
-#else
-gint playlist_get_current_length();
-#define PLAYLIST_GET_CURRENT_LENGTH playlist_get_current_length()
-#endif
-#ifdef HAVE_PLAYLIST_GET_FILENAME
-gchar *playlist_get_filename(gint pos);
-#endif
-gchar *playlist_get_songtitle(gint pos);
+#include "player.h"
+
+/* utilities */
+void xfade_usleep(gint usec);
 
 /* config change callbacks */
 void xfade_realize_config();
@@ -502,8 +487,8 @@ typedef struct
 	gboolean oss_maxbuf_enable;
 
 	/* output: plugin */
-	gchar *op_config_string;	/* stores configs for all plugins */
-	gchar *op_name;		/* name of the current plugin */
+	gchar *op_config_string;  /* stores configs for all plugins */
+	gchar *op_name;           /* name of the current plugin */
 
 	/* effects */
 	gchar *ep_name;
@@ -567,22 +552,30 @@ extern config_t *config;
 extern config_t  config_default;
 extern buffer_t *buffer;
 
-#if defined(HAVE_GLIB_STATIC_MUTEX)
+#if defined(HAVE_GLIB_THREADS)
 #  define MUTEX GStaticMutex
 #  define MUTEX_LOCK(mutex)   g_static_mutex_lock(mutex)
 #  define MUTEX_UNLOCK(mutex) g_static_mutex_unlock(mutex)
 #  define MUTEX_INITIALIZER   G_STATIC_MUTEX_INIT
 #  define THREAD GThread *
-#  define THREAD_EXIT(rval)   g_thread_exit(rval)
-#  define THREAD_JOIN(thread) g_thread_join(thread)
+#  define THREAD_CREATE(thread,func) !(thread = g_thread_create(func, NULL, TRUE, NULL))
+#  define THREAD_EXIT(rval)          g_thread_exit(rval)
+#  define THREAD_JOIN(thread)        g_thread_join(thread)
+#  define SCHED_YIELD                g_thread_yield()
 #else
 #  define MUTEX pthread_mutex_t
 #  define MUTEX_LOCK(mutex)   pthread_mutex_lock(mutex)
 #  define MUTEX_UNLOCK(mutex) pthread_mutex_unlock(mutex)
 #  define MUTEX_INITIALIZER   PTHREAD_MUTEX_INITIALIZER
 #  define THREAD pthread_t
-#  define THREAD_EXIT(rval)   pthread_exit(rval)
-#  define THREAD_JOIN(thread) pthread_join(thread,NULL)
+#  define THREAD_CREATE(thread,func) pthread_create(&thread,NULL,func,NULL)
+#  define THREAD_EXIT(rval)          pthread_exit(rval)
+#  define THREAD_JOIN(thread)        pthread_join(thread,NULL)
+#  if defined(_POSIX_PRIORITY_SCHEDULING)
+#    define SCHED_YIELD sched_yield()
+#  else
+#    define SCHED_YIELD { }
+#  endif
 #endif
 
 extern gboolean opened;		/* XMMS-crossfade is opened */
@@ -591,6 +584,6 @@ extern gint     output_offset;
 extern gint64   output_streampos;
 
 extern OutputPlugin *the_op;
-extern gint the_rate;
+extern gint          the_rate;
 
 #endif /* _CROSSFADE_H_ */
