@@ -29,21 +29,21 @@
 #include "effect.h"
 
 void
-effect_init(effect_context_t * ec, EffectPlugin * ep)
+effect_init(effect_context_t *ec, EffectPlugin *ep)
 {
 	memset(ec, 0, sizeof(*ec));
 	effect_set_plugin(ec, ep);
 }
 
 static char *
-plugin_name(EffectPlugin * ep)
+plugin_name(EffectPlugin *ep)
 {
 	return ep->description ? ep->description : "<unnamed>";
 }
 
 
 void
-effect_set_plugin(effect_context_t * ec, EffectPlugin * ep)
+effect_set_plugin(effect_context_t *ec, EffectPlugin *ep)
 {
 	if (ec->use_xmms_plugin && (ep == EFFECT_USE_XMMS_PLUGIN))
 		return;
@@ -79,13 +79,13 @@ effect_set_plugin(effect_context_t * ec, EffectPlugin * ep)
 }
 
 gint
-effect_flow(effect_context_t * ec, gpointer * buffer, gint length, format_t * format, gboolean allow_format_change)
+effect_flow(effect_context_t *ec, gpointer * buffer, gint length, format_t * format, gboolean allow_format_change)
 {
 	EffectPlugin *ep;
 
-	if (ec->use_xmms_plugin ? effects_enabled() : (ec->ep != NULL))
+	if (ec->use_xmms_plugin ? xfplayer_effects_enabled() : (ec->ep != NULL))
 	{
-		ep = ec->use_xmms_plugin ? get_current_effect_plugin() : ec->ep;
+		ep = ec->use_xmms_plugin ? xfplayer_get_current_effect_plugin() : ec->ep;
 
 		if (ep != ec->last_ep)
 		{
@@ -160,7 +160,7 @@ effect_flow(effect_context_t * ec, gpointer * buffer, gint length, format_t * fo
 }
 
 void
-effect_free(effect_context_t * ec)
+effect_free(effect_context_t *ec)
 {
 	/* nothing to do */
 }
