@@ -320,7 +320,7 @@ xfade_update_monitor(gpointer userdata)
 	}
 
 	/*** Position ***/
-	if (!get_input_playing() || (monitor_closing == CLOSED))  /* XMMS */
+	if (!xfplayer_input_playing() || (monitor_closing == CLOSED))
 	{
 		gtk_label_set_text(monitor_position_label, default_position_str);
 		gtk_label_set_text(monitor_total_label, default_total_str);
@@ -330,7 +330,7 @@ xfade_update_monitor(gpointer userdata)
 	{
 		gchar buffer[32];
 		gint position = output_time - output_offset;
-		gint total    = PLAYLIST_GET_CURRENT_LENGTH;  /* XMMS */
+		gint total    = xfplaylist_current_length();
 		gint left     = total - position;
 
 		/* position */
@@ -437,7 +437,7 @@ xfade_stop_monitor()
 	/* HACK, ugly HACK: force a final call of xfade_update_monitor */
 	monitor_closing = CLOSING;
 	while ((monitor_closing == CLOSING) && (max_wait-- > 0))
-		xmms_usleep(10000);
+		xfade_usleep(10000);
 
 	if (max_wait <= 0)
 		DEBUG(("[crossfade] stop_monitor: timeout!\n"));
@@ -452,7 +452,7 @@ void input_seek(int time);  /* XMMS */
 void
 on_monitor_seekeof_button_clicked(GtkButton *button, gpointer user_data)
 {  
-	gint total    = PLAYLIST_GET_CURRENT_LENGTH;  /* XMMS */
+	gint total    = xfplaylist_current_length();
 	gint offset   = xfade_cfg_offset(&config->fc[FADE_CONFIG_XFADE])
 	              - config->songchange_timeout;
 	gint position = total + offset - 2500;
