@@ -29,6 +29,7 @@
 #include "effect.h"
 #include "format.h"
 #include "oss.h"
+#include "player.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -45,8 +46,6 @@
 #  include <machine/soundcard.h>
 #endif
 
-#define USE_PTHREAD_JOIN
-
 
 /* output plugin callback prototypes */
 static void oss_get_volume(int *l, int *r);
@@ -62,14 +61,27 @@ static gint oss_output_time();
 static gint oss_written_time();
 
 /* output plugin callback table */
+#if defined (COMPILE_FOR_AUDACIOUS)
+static OutputPlugin oss_op = {
+	.description    = "Builtin OSS Driver",
+	.get_volume     = oss_get_volume,
+	.set_volume     = oss_set_volume,
+	.open_audio     = oss_open_audio,
+	.write_audio    = oss_write_audio,
+	.close_audio    = oss_close_audio,
+	.flush          = oss_flush,
+	.pause          = oss_pause,
+	.buffer_free    = oss_buffer_free,
+	.buffer_playing = oss_buffer_playing,
+	.output_time    = oss_output_time,
+	.written_time   = oss_written_time,
+};
+#else
 static OutputPlugin oss_op = {
 	NULL,
 	NULL,
 	"Builtin OSS Driver",
 	NULL,
-#if defined (COMPILE_FOR_AUDACIOUS)
-	NULL,
-#endif
 	NULL,	
 	NULL,
 	oss_get_volume,
@@ -83,10 +95,8 @@ static OutputPlugin oss_op = {
 	oss_buffer_playing,
 	oss_output_time,
 	oss_written_time,
-#if defined(COMPILE_FOR_AUDACIOUS)
-	NULL,
-#endif
 };
+#endif
 
 /* local prototypes */
 static void *buffer_thread_f(void *arg);
@@ -100,8 +110,8 @@ static gint dsp_fragment_size    =  0;
 static gint dsp_fragment_utime   =  0;
 static gboolean dsp_select_works = FALSE;
 
-static MUTEX buffer_mutex = MUTEX_INITIALIZER;
-static pthread_t buffer_thread;
+static MUTEX     buffer_mutex = MUTEX_INITIALIZER;
+static THREAD    buffer_thread;
 static gboolean  buffer_thread_finished;
 
 static format_t format;
@@ -245,8 +255,6 @@ oss_open_audio(AFormat fmt, int rate, int nch)
 	struct timeval tv;
 	fd_set set;
 
-	pthread_attr_t attr;
-
 	DEBUG(("[xfade-oss] open_audio: pid=%d\n", getpid()));
 
 	/* check if we should use as much device buffer as available */
@@ -256,7 +264,7 @@ oss_open_audio(AFormat fmt, int rate, int nch)
 		dsp_fragment = config->oss_fragments << 16 | config->oss_fragment_size;
 
 	/* check for realtime priority, it needs some special attention */
-	realtime = xmms_check_realtime_priority();
+	realtime = xfplayer_check_realtime_priority();
 
 	DEBUG(("[xfade-oss] open_audio: fmt=%s rate=%d nch=%d\n", format_name(fmt), rate, nch));
 
@@ -452,16 +460,9 @@ oss_open_audio(AFormat fmt, int rate, int nch)
 
 	/* create and run buffer thread (detached) */
 	buffer_thread_finished = FALSE;
-	pthread_attr_init(&attr);
-	pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
-#ifdef USE_PTHREAD_JOIN
-	if (pthread_create(&buffer_thread, NULL, buffer_thread_f, NULL))
-#else
-	if (pthread_create(&buffer_thread, &attr, buffer_thread_f, NULL))
-#endif
+	if (THREAD_CREATE(buffer_thread, buffer_thread_f))
 	{
-		PERROR("[xfade-oss] open_audio: pthread_create()");
-		pthread_attr_destroy(&attr);
+		PERROR("[xfade-oss] open_audio: thread_create()");
 		buffer_thread_finished = TRUE;
 		g_free(buffer_data);
 		buffer_data = NULL;
@@ -469,7 +470,6 @@ oss_open_audio(AFormat fmt, int rate, int nch)
 		dsp_fd = -1;
 		return 0;
 	}
-	pthread_attr_destroy(&attr);
 
 	/* done */
 	return 1;
@@ -505,7 +505,7 @@ oss_write_audio(void *ptr, int length)
 	streampos += length;
 
 	/* apply effect FIXME: reenable format change */
-	length = effect_flow(&effect_context, (gpointer *) & ptr, length, &format, FALSE);
+	length = effect_flow(&effect_context, (gpointer *) &ptr, length, &format, FALSE);
 
 	/* Update preload. The buffer thread will not write any
 	 * data to the device before preload is decreased below 1. */
@@ -568,7 +568,7 @@ buffer_thread_f(void *arg)
 				PERROR("[xfade-oss] buffer_thread_f: select()");
 #if 1
 				MUTEX_UNLOCK(&buffer_mutex);
-				xmms_usleep(dsp_fragment_utime);
+				xfade_usleep(dsp_fragment_utime);
 				MUTEX_LOCK(&buffer_mutex);
 				continue;
 #else
@@ -581,7 +581,7 @@ buffer_thread_f(void *arg)
 		else
 		{
 			MUTEX_UNLOCK(&buffer_mutex);
-			xmms_usleep(dsp_fragment_utime);
+			xfade_usleep(dsp_fragment_utime);
 			MUTEX_LOCK(&buffer_mutex);
 		}
 
@@ -644,7 +644,7 @@ buffer_thread_f(void *arg)
 			 *       Without it this thread would eat up all CPU time polling
 			 *       the audio device with select(), having no samples to write. */
 			MUTEX_UNLOCK(&buffer_mutex);
-			xmms_usleep(dsp_fragment_utime / 4);
+			xfade_usleep(dsp_fragment_utime / 4);
 			MUTEX_LOCK(&buffer_mutex);
 		}
 	}
@@ -655,7 +655,7 @@ buffer_thread_f(void *arg)
 	DEBUG(("[xfade-oss] buffer_thread_f: thread finished\n"));
 	buffer_thread_finished = TRUE;
 #ifdef USE_PTHREAD_JOIN
-	pthread_exit(0);
+	THREAD_EXIT(0);
 #endif
 	return NULL;
 }
@@ -682,11 +682,11 @@ oss_close_audio()
 
 	/* wait for buffer thread to terminate */
 #ifdef USE_PTHREAD_JOIN
-	if (pthread_join(buffer_thread, NULL))
+	if (THREAD_JOIN(buffer_thread, NULL))
 		PERROR("[xfade-oss] close_audio: pthread_join()");
 #else	
 	while (!buffer_thread_finished)
-		xmms_usleep(10000);
+		xfade_usleep(10000);
 #endif		
 
 	/* free effect private data */
