@@ -1,12 +1,12 @@
 #!/bin/bash
 #
-# try to merge media-sound/xmms-1.2.10-r15 with custom patches
+# try to merge media-sound/xmms-1.2.10-r16 with custom patches
 #
 source /etc/make.globals
 source /etc/make.conf
 
-EBUILD="$PORTDIR/media-sound/xmms/xmms-1.2.10-r15.ebuild"
-SRCDIR="$PORTAGE_TMPDIR/portage/xmms-1.2.10-r15/work/xmms-1.2.10"
+EBUILD="$PORTDIR/media-sound/xmms/xmms-1.2.10-r16.ebuild"
+SRCDIR="$PORTAGE_TMPDIR/portage/xmms-1.2.10-r16/work/xmms-1.2.10"
 
 #
 # emerge clean
@@ -22,11 +22,11 @@ fi
 # patch
 #
 echo -n "Patching XMMS..."
-if ! patch --batch -N -d "$SRCDIR" -p1 <xmms-1.2.10-gentoo-r15.patch >/dev/null
+if ! patch --batch -N -d "$SRCDIR" -p1 <xmms-ALL-1.2.10-gentoo-r16.patch >/dev/null
 then
 	echo " failed!"
 	echo -n "Trying dry-run of reverse patch..."
-	if ! patch --batch --dry-run -R -d "$SRCDIR" -p1 <xmms-1.2.10-gentoo-r15.patch >/dev/null
+	if ! patch --batch --dry-run -R -d "$SRCDIR" -p1 <xmms-ALL-1.2.10-gentoo-r16.patch >/dev/null
 	then
 		echo " failed!"
 		exit 1
