@@ -91,7 +91,8 @@ rate_config(rate_context_t *rc, gint in_rate, gint out_rate, int converter_type)
 {
 	if ((in_rate <= 0) || (in_rate > MAX_RATE) || (out_rate <= 0) || (out_rate > MAX_RATE))
 	{
-		DEBUG(("[crossfade] rate_config: " "illegal rates (in=%d, out=%d)!\n", in_rate, out_rate));
+		DEBUG(("[crossfade] rate_config: "
+		       "illegal rates (in=%d, out=%d)!\n", in_rate, out_rate));
 		return;
 	}
 
@@ -149,10 +150,12 @@ realloc_if_needed(gpointer * pointer, gint * size, gint req_size)
 }
 
 gint16
-final_quantize(volume_context_t * vc, gfloat v, gfloat scale)
+final_quantize(volume_context_t *vc, gfloat v, gfloat scale)
 {
+#if 0
 	if (config->mixer_software)
 		v *= scale;
+#endif
 
 	v = rintf(v);
 	if (v > 32767 || v < -32768)
@@ -165,7 +168,7 @@ final_quantize(volume_context_t * vc, gfloat v, gfloat scale)
 }
 
 gint
-rate_flow(rate_context_t *rc, gpointer * buffer, gint length)
+rate_flow(rate_context_t *rc, gpointer *buffer, gint length)
 {
 	gint size;
 	gfloat volume_scale_l = 1, volume_scale_r = 1;
@@ -209,7 +212,7 @@ rate_flow(rate_context_t *rc, gpointer * buffer, gint length)
 		assert(error != -1);
 		int_p2 = rc->data;
 
-		length /= 4;	/* 2 channels x 2 bytes */
+		length /= 4;  /* 2 channels x 2 bytes */
 		for (i = 0; i < length; i++)
 		{
 			gfloat v_l = *(int_p++);
@@ -224,7 +227,7 @@ rate_flow(rate_context_t *rc, gpointer * buffer, gint length)
 
 #ifdef HAVE_LIBSAMPLERATE
 	assert(length % 4 == 0);
-	length /= 4;		/* 2 channels x 2 bytes */
+	length /= 4;  /* 2 channels x 2 bytes */
 	/* safe upper bound of output length: */
 	out_bound = (gint) ceil((rc->src_data.src_ratio + 0.05) * length);
 
@@ -352,7 +355,7 @@ rate_flow(rate_context_t *rc, gpointer * buffer, gint length)
 			rc->out_ofs = rc->in_ofs = 0;
 	}
 
-	return 0;		/* program flow never reaches this point */
+	return 0;  /* program flow never reaches this point */
 #endif
 }
 
