@@ -38,23 +38,25 @@ typedef struct
 	gboolean active;
 	gint target_rms;
 	gint song_rms;
-	gfloat factor;
+	gfloat factor_l;
+	gfloat factor_r;
 
 	struct timeval tv_last;
 	gint clips;
 }
 volume_context_t;
 
-void volume_init(volume_context_t * cc);
-void volume_flow(volume_context_t * cc, gpointer * buffer, gint length);
-void volume_free(volume_context_t * cc);
+void volume_init(volume_context_t *vc);
+void volume_flow(volume_context_t *vc, gint16 *buffer, gint length);
+void volume_free(volume_context_t *vc);
 
-void volume_set_active(volume_context_t * cc, gboolean active);
-void volume_set_target_rms(volume_context_t * cc, gint target_rms);
-void volume_set_song_rms(volume_context_t * cc, gint song_rms);
+void volume_set(volume_context_t *vc, gint l, gint r);
 
-gfloat volume_compute_factor(gint percent, gint dB_range);	/*compute factor corresponding to
-								   attenuations in [- dB_range, 0]
-								 */
+void volume_set_active    (volume_context_t *vc, gboolean active);
+void volume_set_target_rms(volume_context_t *vc, gint target_rms);
+void volume_set_song_rms  (volume_context_t *vc, gint song_rms);
+
+/* compute factor corresponding to attenuations in [- dB_range, 0] */
+gfloat volume_compute_factor(gint percent, gint dB_range);
 
 #endif /* _VOLUME_H_ */
